pub struct DynamicRayCastVehicleController {
pub current_vehicle_speed: f32,
pub chassis: RigidBodyHandle,
pub index_up_axis: usize,
pub index_forward_axis: usize,
/* private fields */
}Expand description
A character controller to simulate vehicles using ray-casting for the wheels.
Fields
current_vehicle_speed: f32The current forward speed of the vehicle.
chassis: RigidBodyHandleHandle of the vehicle’s chassis.
index_up_axis: usizeThe chassis’ local up direction (0 = x, 1 = y, 2 = z)
index_forward_axis: usizeThe chassis’ local forward direction (0 = x, 1 = y, 2 = z)
Implementations
Sourceimpl DynamicRayCastVehicleController
impl DynamicRayCastVehicleController
Sourcepub fn new(chassis: RigidBodyHandle) -> Self
pub fn new(chassis: RigidBodyHandle) -> Self
Creates a new vehicle represented by the given rigid-body.
Wheels have to be attached afterwards calling Self::add_wheel.
Sourcepub fn add_wheel(
&mut self,
chassis_connection_cs: Point<f32>,
direction_cs: Vector<f32>,
axle_cs: Vector<f32>,
suspension_rest_length: f32,
radius: f32,
tuning: &WheelTuning,
) -> &mut Wheel
pub fn add_wheel( &mut self, chassis_connection_cs: Point<f32>, direction_cs: Vector<f32>, axle_cs: Vector<f32>, suspension_rest_length: f32, radius: f32, tuning: &WheelTuning, ) -> &mut Wheel
Adds a wheel to this vehicle.
Sourcepub fn update_vehicle(&mut self, dt: f32, queries: QueryPipelineMut<'_>)
pub fn update_vehicle(&mut self, dt: f32, queries: QueryPipelineMut<'_>)
Updates the vehicle’s velocity based on its suspension, engine force, and brake.
Sourcepub fn wheels_mut(&mut self) -> &mut [Wheel]
pub fn wheels_mut(&mut self) -> &mut [Wheel]
Mutable reference to all the wheels attached to this vehicle.